@@ -6,6 +6,9 @@ DIR=otrs-*
 
 tar -x -z -f $3 --exclude '*/doc/manual*'
 rm -rf $DIR/var/httpd/htdocs/yui/2.7.0
+rm -rf $DIR/var/httpd/htdocs/js/thirdparty/jquery-1.*
+rm -rf $DIR/var/httpd/htdocs/js/thirdparty/jquery
+rm -rf $DIR/var/httpd/htdocs/js/thirdparty/jquery-ui-1.*
 tar -c -z -f $3 $DIR
 rm -rf $DIR
 
